# scikit-genome

_scikit-genome_ is a Python package for genomics.

* Essential, efficient algorithms for genomics
* Interoperable with Python’s scientific ecosystem 
* Free and open-source

## Frequently asked questions (FAQ)

### How do I pronounce “scikit-genome?”

*sī kit ˈjēˌnōm* is the preferred pronunciation.

### What’s a “scikit?”

scikit-genome is a SciPy toolkit. It’s compatible with both SciPy toolkits like scikit-learn and NumPy-compatible packages like PyTorch and TensorFlow.

### What’s the inclusion criteria for new algorithms?

Maintainers consider only well-established algorithms for inclusion. A minimum of three years since publication, more than 200 citations, and far-reaching usefulness is expected. Methods that provide clear-cut improvements on widely-used algorithms will also be considered.

Methods provided by one of the following maintained, general-purpose packages **won’t** be considered for inclusion:

* matplotlib
* NumPy
* Pandas
* PyTorch
* scikit-image
* scikit-learn
* SciPy
* statsmodels
* TensorFlow

### Do you support PyPy?

Yes
